@@ -46,8 +46,10 @@ def version():
         - .adminclass增加注释和使用说明        # 2.4.4
         - bulk_delete增加权限控制        # 2.4.5
         - order_by_order_type_ls修复为[""]的时候出现的bug
+        - 页码p的提示更人性化, 改为必须正整数        # 2.4.6
+        - 页码p或page_size等于GET_ALL(-999)时, 则返回全部数据
     """
-    v = "2.4.5"  # 当前: 2.4.5
+    v = "2.4.6"  # 当前: 2.4.6
     return v
 
 
